import { TypesUtils } from '@utils-fns/utils';

type MinMaxParamsEmail = {
    min?: number;
    max?: number;
};
type ParamsValidatorEmail = {
    minMaxUserNameEmail?: MinMaxParamsEmail;
    minMaxEmailDomain?: MinMaxParamsEmail;
    emailDomainName?: RegExp;
};
type EmailValidator = {
    email?: string;
    paramsEmailValidator?: ParamsValidatorEmail;
};

type CustomPatternPhone = {
    coutryCode: RegExp;
    areaStateCode: RegExp;
    phoneNumber: RegExp;
};
type ParamsPhoneValidator = {
    onlyMobilePhoneBR?: boolean;
    canReceiveInternationalNumbers?: boolean;
    customPatternPhone?: CustomPatternPhone;
    publicUtilityNumberBR?: boolean;
    numberWithoutCodeAreas?: boolean;
};
type PhoneValidator = {
    phone?: string;
    paramsPhoneValidator?: ParamsPhoneValidator;
};

type TypeCard = 'credit' | 'debit' | 'credit-debit';
type BrandCard = TypesUtils['BrandCardType'];
type ParamsPaymentCardValidator = {
    validationTypeCard?: TypeCard;
    specificBrandCard?: BrandCard;
    customPatternPaymentCard?: RegExp;
};
type PaymentCardValidator = {
    cardNumber?: string;
    paramsPaymentCardValidator?: ParamsPaymentCardValidator;
};

declare const paymentSlipSegmentIdentification: {
    readonly '1': "municipal";
    readonly '2': "sanitation";
    readonly '3': "gas_energy";
    readonly '4': "telecom";
    readonly '5': "government_agencies";
    readonly '6': "others";
    readonly '7': "transit";
    readonly '9': "only_banks";
};
declare const paymentSlipSegmentType: {
    readonly municipal: "Taxas Municipais";
    readonly sanitation: "Taxas de Saneamento";
    readonly gas_energy: "Taxas de Energia Elétrica e Gás";
    readonly telecom: "Taxas de Telecomunicações";
    readonly government_agencies: "Taxas de Órgãos Governamentais";
    readonly transit: "Taxas de Trânsito";
    readonly only_banks: "Uso Exclusivo dos bancos";
    readonly others: "Outros";
};
type ParamsPaymentSlipValidator = {
    validByBank?: TypesUtils['BankNames'] | TypesUtils['BankCode'];
    validSegmentType?: (typeof paymentSlipSegmentType)[keyof typeof paymentSlipSegmentType];
    validByPrice?: string | number;
    validByDate?: string | Date;
    validByTypeOfPaymentSlip?: 'Boleto Bancário' | 'Boleto de Arrecadação';
    validByIfIsBarCodeOrTypeableLine?: 'Cód. Barras' | 'Linha Digitável';
};
type PaymentSlipValidator = {
    digits?: string;
    paramsPaymentSlipValidator?: ParamsPaymentSlipValidator;
};

type TypesValidators = {
    EmailValidator: EmailValidator;
    MinMaxParamsEmail: MinMaxParamsEmail;
    ParamsValidatorEmail: ParamsValidatorEmail;
    PhoneValidator: PhoneValidator;
    ParamsPhoneValidator: ParamsPhoneValidator;
    CustomPatternPhone: CustomPatternPhone;
    BrandCard: BrandCard;
    ParamsPaymentCardValidator: ParamsPaymentCardValidator;
    PaymentCardValidator: PaymentCardValidator;
    TypeCard: TypeCard;
    PaymentSlipSegmentIdentification: typeof paymentSlipSegmentIdentification;
    PaymentSlipSegmentType: typeof paymentSlipSegmentType;
    PaymentSlipValidator: PaymentSlipValidator;
    ParamsPaymentSlipValidator: ParamsPaymentSlipValidator;
};
declare const validators: {
    cpf: (cpf?: string | undefined) => boolean;
    cnpj: (cnpj?: string | undefined) => boolean;
    email: ({ email, paramsEmailValidator, }: EmailValidator) => boolean;
    nis: (nis?: string | undefined) => boolean;
    phone: ({ phone, paramsPhoneValidator, }: PhoneValidator) => boolean;
    paymentCardValidator: ({ cardNumber, paramsPaymentCardValidator, }: PaymentCardValidator) => boolean;
    paymentSlipValidator: ({ digits, paramsPaymentSlipValidator, }: PaymentSlipValidator) => boolean;
};

export { TypesValidators, validators };
